#!/usr/bin/env ruby

require 'ROOT'
include ROOT
include Math

app = TApplication.new("My Application",0,[])

gStyle = ROOT::gStyle
gStyle.SetOptLogx(0)
gStyle.SetOptLogy(0)
gStyle.SetTitleYOffset(0)
gStyle.SetTitleXOffset(0)

c1 = TCanvas.new("c1","Ruby-ROOT",200,10,800,800)
chtitle = "Ruby-ROOT Test"
title = TPaveLabel.new(0.1,0.95,0.9,0.99, chtitle)
title.Draw

gStyle.SetOptLogx(1)
gStyle.SetOptLogy(1)
gStyle.SetTitleYOffset(1.3)
gStyle.SetTitleXOffset(1.1)

pad1 = TPad.new("pad1","The pad with the plot",0.03,0.03,0.97,0.92)
pad1.Draw
pad1.cd

# In GeV
egamma = [1.0, 2.0, 3.0, 5.0, 7.0, 10.0, 20.0, 60.0, 300.0]

# In degrees
intall = [6.0, 49.0, 62.0, 91.0, 103.0, 126.0, 122.0, 137.0, 141.0]
res68 = [1.02273, 0.49561, 0.31226, 0.24924, \
               0.15183, 0.106, 0.0487, 0.02578, 0.02005]
res95 = [2.01395, 1.75039, 1.16024, 0.78209, 
               0.47269, 0.29507, 0.23778, 0.14037, 0.06589]
ezero = [0.0]*9
eres68 = []
eres95 = []
for i in 0...9
     eres68 << res68[i]/sqrt(2.0*intall[i])
     eres95 << res95[i]/sqrt(2.0*intall[i])
end
gr1 = TGraphErrors.new(9, egamma, res68, ezero, eres68)
gr2 = TGraphErrors.new(9, egamma, res95, ezero, eres95)

funfit68 = TF1.new("funfit68","sqrt([0]*[0]+[1]*[1]/x/x)",0.0,1000.0)
funfit68.SetParameter(0,0.02)
funfit68.SetParameter(1,1.00)
funfit95 = TF1.new("funfit95","sqrt([0]*[0]+[1]*[1]/x/x)",0.0,1000.0)
funfit95.SetParameter(0,0.10)
funfit95.SetParameter(1,3.00)

gr2.SetLineColor(KBlue)
gr2.SetLineWidth(5)
gr2.SetMarkerStyle(21)
gr2.SetMarkerColor(KBlue)
gr2.SetMarkerSize(1)
gr2.SetTitle("")
gr2.Draw("AP")
gr2.GetHistogram.SetMinimum(0.01)
gr2.GetHistogram.SetXTitle("My variable (GeV)")
gr2.GetHistogram.SetYTitle("Resolution (arb. units)")
gr2.Fit("funfit95")
gr2.Draw("AP")
  
gr1.SetLineColor(KRed)
gr1.SetLineWidth(5)
gr1.SetMarkerStyle(20)
gr1.SetMarkerColor(KRed)
gr1.SetMarkerSize(1)
gr1.SetTitle("")
gr1.Fit("funfit68")
gr1.Draw("P")

t = TText.new
t.SetTextColor(1)
t.SetTextSize(0.04)
t.SetTextAlign(12)
t.DrawText(1.8,0.03,"95% containment")
t.DrawText(1.8,0.05,"68% containment")
t.DrawText(20.0,0.4,"`s#?95!(E) = 0.074 '1# 3.4/E")
t.DrawText(20.0,0.015,"`s#?68!(E) = 0.019 '1# 1.01/E")

t.SetTextSize(0.03)
graph1 = TGraph.new(1, [0.0], [0.0])
graph1.SetMarkerColor(KBlue)
graph1.SetMarkerStyle(21)
graph1.SetMarkerSize(2)
graph1.SetPoint(0,1.5,0.03)
graph1.Draw("P")
graph2 = TGraph.new(1, [0.0], [0.0])
graph2.SetMarkerColor(KRed)
graph2.SetMarkerStyle(20)
graph2.SetMarkerSize(2)
graph2.SetPoint(0,1.5,0.05)
graph2.Draw("P")

c1.Modified
c1.Update
c1.SaveAs("resolution.eps")

app.Run
